/*
** Copyright (C) 2001-2026 Zabbix SIA
**
** This program is free software: you can redistribute it and/or modify it under the terms of
** the GNU Affero General Public License as published by the Free Software Foundation, version 3.
**
** This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
** without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
** See the GNU Affero General Public License for more details.
**
** You should have received a copy of the GNU Affero General Public License along with this program.
** If not, see <https://www.gnu.org/licenses/>.
**/


class CWidgetFieldSeverities extends CWidgetField {

	/**
	 * @type {HTMLInputElement[]}
	 */
	#checkboxes;

	constructor({name, form_name}) {
		super({name, form_name});

		this.#checkboxes = [...this.getForm().querySelectorAll(`input[type="checkbox"][name^="${name}["]`)];

		this.#initField();
	}

	#initField() {
		for (const checkbox of this.#checkboxes) {
			checkbox.addEventListener('change', () => this.dispatchUpdateEvent());
		}
	}
}
